/*
 * Copyright (c) 2018 Robert Turnbull
 * 
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 * 
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 * 
 */

#import "ViewController.h"

@interface ViewController ()

@end

@implementation ViewController

- (void)viewDidLoad {
    [super viewDidLoad];
    // Do any additional setup after loading the view, typically from a nib.
    
    _fontArray = [NSArray arrayWithObjects:@"Estrangelo Antioch",@"Estrangelo Edessa",@"Estrangelo Midyat",@"Estrangelo Nisibin",@"Estrangelo Quenneshrin",@"Estrangelo Talada",@"Estrangelo TurAbdin",@"East Syriac Adiabene",@"East Syriac Ctesiphon",@"Serto Batnan",@"Serto Jerusalem",@"Serto Kharput",@"Serto Malankara",@"Serto Mardin",@"Serto Urhoy",nil];
    
    // Connect data
    _fontPicker.dataSource = self;
    _fontPicker.delegate = self;
    [self resetFont];
    
    /* Reset font on orientation change */
    [[UIDevice currentDevice] beginGeneratingDeviceOrientationNotifications];
    [[NSNotificationCenter defaultCenter]
     addObserver:self selector:@selector(orientationChanged:)
     name:UIDeviceOrientationDidChangeNotification
     object:[UIDevice currentDevice]];
}

- (void)didReceiveMemoryWarning {
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

// The number of columns of data
- (NSInteger)numberOfComponentsInPickerView:(UIPickerView *)pickerView{
    return 1;
}

// The number of rows of data
- (NSInteger)pickerView:(UIPickerView *)pickerView numberOfRowsInComponent:(NSInteger)component {
    return _fontArray.count;
}

// The data to return for the row and component (column) that's being passed in
- (NSString*)pickerView:(UIPickerView *)pickerView titleForRow:(NSInteger)row forComponent:(NSInteger)component {
    return _fontArray[row];
}

- (void)pickerView:(UIPickerView *)pickerView didSelectRow:(NSInteger)row inComponent:(NSInteger)component {
    [self resetFont];
}

-(void) orientationChanged:(id)data {
    [self resetFont];
}

-(void) resetFont {
    /* Get fontname from picker */
    if ( _fontPicker == NULL || _textView == NULL )
        return;
    NSUInteger rowIndex = [_fontPicker selectedRowInComponent:0];
    if ( rowIndex >= [_fontArray count] )
        return;
    NSString* fontName = _fontArray[rowIndex];
    
    /* Fit font to size of box */
    CGFloat fontSize = 200.0;
    CGFloat minSize = 10.0;
    do {
        UIFont* font = [UIFont fontWithName:fontName size:fontSize];
        [_textView setFont:font];
        fontSize -= 1.0;
    } while (fontSize > minSize &&  [_textView sizeThatFits:(CGSizeMake(_textView.frame.size.width, FLT_MAX))].height >= _textView.frame.size.height );

}


@end
